@@ -17,6 +17,8 @@
  */
 package nl.mpi.flap.model;
 
+import java.util.List;
+
 /**
  * Document : PluginDataNode <br> Created on Sep 10, 2012, 6:09:01 PM <br>
  *
@@ -28,16 +30,27 @@ public interface PluginDataNode {
      * @return The string identifier for this node, please note that this is not
      * an archive handle and will only be relevant to the implementation.
      */
-    public abstract String getID();
+    String getID() throws ModelException;
 
     /**
      * @return The note type object for this data node
      */
-    public abstract PluginDataNodeType getType();
+    PluginDataNodeType getType();
+
+    /**
+     * @return The display label for this data node
+     */
+    String getLabel();
+
+    /**
+     * @return all fields arranged into field group objects for this data node
+     */
+    List<FieldGroup> getFieldGroups();
+
     /**
      * Gets an array of the children of this node.
      *
      * @return An array of the next level child nodes.
      */
-//    public abstract List<? extends PluginDataNode> getChildList();
+    List<? extends PluginDataNode> getChildList();
 }
